
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "kcalendarcore_python.h"

// main header
#include "kcalendarcore_recurrence_wrapper.h"

// Wrappers providing overrides
#include "kcalendarcore_recurrencerule_ruleobserver_wrapper.h"

// inner classes
#include "kcalendarcore_recurrence_recurrenceobserver_wrapper.h"

// Argument includes
#include <QList>
#include <period.h>
#include <qbitarray.h>
#include <qdatastream.h>
#include <qdatetime.h>
#include <qtimezone.h>
#include <recurrence.h>
#include <recurrencerule.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace KCalendarCore;

extern "C" {
static PyTypeObject *Sbk_KCalendarCore_Recurrence_TypeF(void)
{
    return SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX].type;
}
} // extern "C"

// Native ---------------------------------------------------------

void RecurrenceWrapper::resetPyMethodCache()
{
    std::fill(m_PyMethodCache.begin(), m_PyMethodCache.end(), nullptr);
}

RecurrenceWrapper::RecurrenceWrapper()
{
}

void RecurrenceWrapper::recurrenceChanged(::KCalendarCore::RecurrenceRule * arg__1)
{
    static const char *funcName = "recurrenceChanged";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Recurrence_TypeF(), gil, funcName, m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Recurrence::recurrenceChanged(arg__1);
    }
    RuleObserverWrapper::sbk_o_recurrenceChanged("Recurrence", funcName, gil, pyOverride, arg__1);
}

RecurrenceWrapper::~RecurrenceWrapper()
{
    auto *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this, Sbk_KCalendarCore_Recurrence_TypeF());
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_KCalendarCore_Recurrence_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::KCalendarCore::Recurrence >()))
        return -1;

    RecurrenceWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "Recurrence", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: Recurrence::Recurrence()
    // 1: Recurrence::Recurrence(const KCalendarCore::Recurrence&)
    if (numArgs == 0) {
        overloadId = 0; // Recurrence()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), (pyArgs[0])))) {
        overloadId = 1; // Recurrence::Recurrence(const KCalendarCore::Recurrence&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // Recurrence()
        {

            // Recurrence::Recurrence()
            cptr = new RecurrenceWrapper();
            break;
        }
        case 1: // Recurrence(const KCalendarCore::Recurrence &r)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::KCalendarCore::Recurrence *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Recurrence::Recurrence(const KCalendarCore::Recurrence&)
                cptr = new RecurrenceWrapper(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< KCalendarCore::Recurrence >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_addExDate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::addExDate(const QDate&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
        overloadId = 0; // Recurrence::addExDate(const QDate&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addExDate", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDate cppArg0_local;
        ::QDate *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::addExDate(const QDate&)
            cppSelf->addExDate(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_addExDateTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::addExDateTime(const QDateTime&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // Recurrence::addExDateTime(const QDateTime&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addExDateTime", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::addExDateTime(const QDateTime&)
            cppSelf->addExDateTime(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_addExRule(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::addExRule(KCalendarCore::RecurrenceRule*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), (pyArg)))) {
        overloadId = 0; // Recurrence::addExRule(KCalendarCore::RecurrenceRule*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addExRule", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::KCalendarCore::RecurrenceRule *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::addExRule(KCalendarCore::RecurrenceRule*)
            cppSelf->addExRule(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_addMonthlyDate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::addMonthlyDate(short)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArg)))) {
        overloadId = 0; // Recurrence::addMonthlyDate(short)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addMonthlyDate", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        short cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::addMonthlyDate(short)
            cppSelf->addMonthlyDate(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_addMonthlyPos(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addMonthlyPos", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Recurrence::addMonthlyPos(short,const QBitArray&)
    // 1: Recurrence::addMonthlyPos(short,ushort)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[0])))) {
        if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<ushort>(), (pyArgs[1])))) {
            overloadId = 1; // Recurrence::addMonthlyPos(short,ushort)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBitArray_IDX]), (pyArgs[1])))) {
            overloadId = 0; // Recurrence::addMonthlyPos(short,const QBitArray&)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addMonthlyPos", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // addMonthlyPos(short pos, const QBitArray &days)
        {
            short cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QBitArray cppArg1_local;
            ::QBitArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // Recurrence::addMonthlyPos(short,const QBitArray&)
                cppSelf->addMonthlyPos(cppArg0, *cppArg1);
            }
            break;
        }
        case 1: // addMonthlyPos(short pos, ushort day)
        {
            short cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ushort cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Recurrence::addMonthlyPos(short,ushort)
                cppSelf->addMonthlyPos(cppArg0, cppArg1);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_addObserver(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::addObserver(KCalendarCore::Recurrence::RecurrenceObserver*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_RecurrenceObserver_IDX]), (pyArg)))) {
        overloadId = 0; // Recurrence::addObserver(KCalendarCore::Recurrence::RecurrenceObserver*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addObserver", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::KCalendarCore::Recurrence::RecurrenceObserver *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::addObserver(KCalendarCore::Recurrence::RecurrenceObserver*)
            cppSelf->addObserver(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_addRDate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::addRDate(const QDate&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
        overloadId = 0; // Recurrence::addRDate(const QDate&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addRDate", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDate cppArg0_local;
        ::QDate *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::addRDate(const QDate&)
            cppSelf->addRDate(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_addRDateTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::addRDateTime(const QDateTime&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // Recurrence::addRDateTime(const QDateTime&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addRDateTime", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::addRDateTime(const QDateTime&)
            cppSelf->addRDateTime(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_addRDateTimePeriod(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::addRDateTimePeriod(const KCalendarCore::Period&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Period_IDX]), (pyArg)))) {
        overloadId = 0; // Recurrence::addRDateTimePeriod(const KCalendarCore::Period&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addRDateTimePeriod", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::KCalendarCore::Period cppArg0_local;
        ::KCalendarCore::Period *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::addRDateTimePeriod(const KCalendarCore::Period&)
            cppSelf->addRDateTimePeriod(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_addRRule(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::addRRule(KCalendarCore::RecurrenceRule*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), (pyArg)))) {
        overloadId = 0; // Recurrence::addRRule(KCalendarCore::RecurrenceRule*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addRRule", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::KCalendarCore::RecurrenceRule *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::addRRule(KCalendarCore::RecurrenceRule*)
            cppSelf->addRRule(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_addWeeklyDays(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::addWeeklyDays(const QBitArray&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBitArray_IDX]), (pyArg)))) {
        overloadId = 0; // Recurrence::addWeeklyDays(const QBitArray&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addWeeklyDays", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBitArray cppArg0_local;
        ::QBitArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::addWeeklyDays(const QBitArray&)
            cppSelf->addWeeklyDays(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_addYearlyDate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::addYearlyDate(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // Recurrence::addYearlyDate(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addYearlyDate", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::addYearlyDate(int)
            cppSelf->addYearlyDate(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_addYearlyDay(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::addYearlyDay(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // Recurrence::addYearlyDay(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addYearlyDay", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::addYearlyDay(int)
            cppSelf->addYearlyDay(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_addYearlyMonth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::addYearlyMonth(short)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArg)))) {
        overloadId = 0; // Recurrence::addYearlyMonth(short)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addYearlyMonth", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        short cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::addYearlyMonth(short)
            cppSelf->addYearlyMonth(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_addYearlyPos(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addYearlyPos", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Recurrence::addYearlyPos(short,const QBitArray&)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBitArray_IDX]), (pyArgs[1])))) {
        overloadId = 0; // Recurrence::addYearlyPos(short,const QBitArray&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addYearlyPos", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        short cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QBitArray cppArg1_local;
        ::QBitArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::addYearlyPos(short,const QBitArray&)
            cppSelf->addYearlyPos(cppArg0, *cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_allDay(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Recurrence::allDay()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->allDay();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Recurrence::clear()
        cppSelf->clear();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_days(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Recurrence::days()const->QBitArray
        QBitArray cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->days();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBitArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_defaultRRule(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "defaultRRule", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    if (PyArg_ParseTuple(args, "|O:defaultRRule", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Recurrence::defaultRRule(bool=)const->KCalendarCore::RecurrenceRule*
    if (numArgs == 0) {
        overloadId = 0; // defaultRRule(bool)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // Recurrence::defaultRRule(bool=)const->KCalendarCore::RecurrenceRule*
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "defaultRRule", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"create", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "defaultRRule", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);
            }
        }
        bool cppArg0 = false;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::defaultRRule(bool=)const->KCalendarCore::RecurrenceRule*
            KCalendarCore::RecurrenceRule * cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->defaultRRule(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_defaultRRuleConst(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Recurrence::defaultRRuleConst()const->KCalendarCore::RecurrenceRule*
        KCalendarCore::RecurrenceRule * cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->defaultRRuleConst();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_deleteExRule(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::deleteExRule(KCalendarCore::RecurrenceRule*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), (pyArg)))) {
        overloadId = 0; // Recurrence::deleteExRule(KCalendarCore::RecurrenceRule*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "deleteExRule", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::KCalendarCore::RecurrenceRule *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::deleteExRule(KCalendarCore::RecurrenceRule*)
            cppSelf->deleteExRule(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_deleteRRule(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::deleteRRule(KCalendarCore::RecurrenceRule*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), (pyArg)))) {
        overloadId = 0; // Recurrence::deleteRRule(KCalendarCore::RecurrenceRule*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "deleteRRule", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::KCalendarCore::RecurrenceRule *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::deleteRRule(KCalendarCore::RecurrenceRule*)
            cppSelf->deleteRRule(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_dump(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Recurrence::dump()const
        const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->dump();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_duration(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Recurrence::duration()const->int
        int cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->duration();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_durationTo(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::durationTo(const QDate&)const->int
    // 1: Recurrence::durationTo(const QDateTime&)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 1; // Recurrence::durationTo(const QDateTime&)const->int
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
        overloadId = 0; // Recurrence::durationTo(const QDate&)const->int
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "durationTo", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // durationTo(const QDate &date) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDate cppArg0_local;
            ::QDate *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // Recurrence::durationTo(const QDate&)const->int
                int cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->durationTo(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
        case 1: // durationTo(const QDateTime &dt) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDateTime cppArg0_local;
            ::QDateTime *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // Recurrence::durationTo(const QDateTime&)const->int
                int cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->durationTo(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_endDate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Recurrence::endDate()const->QDate
        QDate cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->endDate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_endDateTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Recurrence::endDateTime()const->QDateTime
        QDateTime cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->endDateTime();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_exDateTimes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Recurrence::exDateTimes()const->QList<QDateTime>
        QList<QDateTime> cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->exDateTimes();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_QDateTime_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_exDates(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Recurrence::exDates()const->QList<QDate>
        QList<QDate> cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->exDates();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_QDate_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_exRules(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Recurrence::exRules()const->QList<KCalendarCore::RecurrenceRule*>
        QList<KCalendarCore::RecurrenceRule*> cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->exRules();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_KCalendarCore_RecurrenceRulePTR_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_frequency(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Recurrence::frequency()const->int
        int cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->frequency();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_getNextDateTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::getNextDateTime(const QDateTime&)const->QDateTime
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // Recurrence::getNextDateTime(const QDateTime&)const->QDateTime
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "getNextDateTime", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::getNextDateTime(const QDateTime&)const->QDateTime
            QDateTime cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->getNextDateTime(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_getPreviousDateTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::getPreviousDateTime(const QDateTime&)const->QDateTime
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // Recurrence::getPreviousDateTime(const QDateTime&)const->QDateTime
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "getPreviousDateTime", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::getPreviousDateTime(const QDateTime&)const->QDateTime
            QDateTime cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->getPreviousDateTime(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_monthDays(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Recurrence::monthDays()const->QList<int>
        QList<int> cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->monthDays();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_int_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_rDateTimePeriod(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::rDateTimePeriod(const QDateTime&)const->KCalendarCore::Period
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // Recurrence::rDateTimePeriod(const QDateTime&)const->KCalendarCore::Period
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "rDateTimePeriod", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::rDateTimePeriod(const QDateTime&)const->KCalendarCore::Period
            KCalendarCore::Period cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->rDateTimePeriod(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Period_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_rDateTimes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Recurrence::rDateTimes()const->QList<QDateTime>
        QList<QDateTime> cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->rDateTimes();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_QDateTime_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_rDates(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Recurrence::rDates()const->QList<QDate>
        QList<QDate> cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->rDates();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_QDate_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_rRules(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Recurrence::rRules()const->QList<KCalendarCore::RecurrenceRule*>
        QList<KCalendarCore::RecurrenceRule*> cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->rRules();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_KCalendarCore_RecurrenceRulePTR_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_recurReadOnly(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Recurrence::recurReadOnly()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->recurReadOnly();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_recurTimesOn(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "recurTimesOn", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Recurrence::recurTimesOn(const QDate&,const QTimeZone&)const->QList<QTime>
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[1])))) {
        overloadId = 0; // Recurrence::recurTimesOn(const QDate&,const QTimeZone&)const->QList<QTime>
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "recurTimesOn", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDate cppArg0_local;
        ::QDate *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QTimeZone cppArg1_local;
        ::QTimeZone *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::recurTimesOn(const QDate&,const QTimeZone&)const->QList<QTime>
            QList<QTime> cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->recurTimesOn(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_QTime_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_recurrenceChanged(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RuleObserver::recurrenceChanged(KCalendarCore::RecurrenceRule*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), (pyArg)))) {
        overloadId = 0; // RuleObserver::recurrenceChanged(KCalendarCore::RecurrenceRule*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "recurrenceChanged", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::KCalendarCore::RecurrenceRule *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // RuleObserver::recurrenceChanged(KCalendarCore::RecurrenceRule*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::Recurrence::recurrenceChanged(cppArg0)
                : cppSelf->recurrenceChanged(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_recurrenceType([[maybe_unused]] PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] ::KCalendarCore::Recurrence *cppSelf = nullptr;
    if (self)
        cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "recurrenceType", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Recurrence::recurrenceType()const->ushort
    // 1: static Recurrence::recurrenceType(const KCalendarCore::RecurrenceRule*)->ushort
    if (numArgs == 0) {
        overloadId = 0; // recurrenceType()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), (pyArgs[0])))) {
        overloadId = 1; // static Recurrence::recurrenceType(const KCalendarCore::RecurrenceRule*)->ushort
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "recurrenceType", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // recurrenceType() const
        {

            // Recurrence::recurrenceType()const->ushort
            ushort cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->recurrenceType();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<ushort>(), &cppResult);
            break;
        }
        case 1: // recurrenceType(const KCalendarCore::RecurrenceRule *rrule)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::KCalendarCore::RecurrenceRule *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // static Recurrence::recurrenceType(const KCalendarCore::RecurrenceRule*)->ushort
                ushort cppResult = ::KCalendarCore::Recurrence::recurrenceType(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<ushort>(), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_recurs(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Recurrence::recurs()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->recurs();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_recursAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::recursAt(const QDateTime&)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // Recurrence::recursAt(const QDateTime&)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "recursAt", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::recursAt(const QDateTime&)const->bool
            bool cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->recursAt(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_recursOn(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "recursOn", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Recurrence::recursOn(const QDate&,const QTimeZone&)const->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[1])))) {
        overloadId = 0; // Recurrence::recursOn(const QDate&,const QTimeZone&)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "recursOn", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDate cppArg0_local;
        ::QDate *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QTimeZone cppArg1_local;
        ::QTimeZone *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::recursOn(const QDate&,const QTimeZone&)const->bool
            bool cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->recursOn(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_removeExRule(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::removeExRule(KCalendarCore::RecurrenceRule*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), (pyArg)))) {
        overloadId = 0; // Recurrence::removeExRule(KCalendarCore::RecurrenceRule*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeExRule", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::KCalendarCore::RecurrenceRule *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::removeExRule(KCalendarCore::RecurrenceRule*)
            cppSelf->removeExRule(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_removeObserver(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::removeObserver(KCalendarCore::Recurrence::RecurrenceObserver*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_RecurrenceObserver_IDX]), (pyArg)))) {
        overloadId = 0; // Recurrence::removeObserver(KCalendarCore::Recurrence::RecurrenceObserver*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeObserver", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::KCalendarCore::Recurrence::RecurrenceObserver *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::removeObserver(KCalendarCore::Recurrence::RecurrenceObserver*)
            cppSelf->removeObserver(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_removeRRule(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::removeRRule(KCalendarCore::RecurrenceRule*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), (pyArg)))) {
        overloadId = 0; // Recurrence::removeRRule(KCalendarCore::RecurrenceRule*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeRRule", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::KCalendarCore::RecurrenceRule *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::removeRRule(KCalendarCore::RecurrenceRule*)
            cppSelf->removeRRule(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_setAllDay(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::setAllDay(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // Recurrence::setAllDay(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAllDay", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::setAllDay(bool)
            cppSelf->setAllDay(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_setDaily(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::setDaily(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // Recurrence::setDaily(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDaily", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::setDaily(int)
            cppSelf->setDaily(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_setDuration(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::setDuration(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // Recurrence::setDuration(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDuration", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::setDuration(int)
            cppSelf->setDuration(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_setEndDate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::setEndDate(const QDate&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
        overloadId = 0; // Recurrence::setEndDate(const QDate&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setEndDate", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDate cppArg0_local;
        ::QDate *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::setEndDate(const QDate&)
            cppSelf->setEndDate(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_setEndDateTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::setEndDateTime(const QDateTime&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // Recurrence::setEndDateTime(const QDateTime&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setEndDateTime", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::setEndDateTime(const QDateTime&)
            cppSelf->setEndDateTime(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_setExDateTimes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::setExDateTimes(const QList<QDateTime>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_QDateTime_IDX], (pyArg)))) {
        overloadId = 0; // Recurrence::setExDateTimes(const QList<QDateTime>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setExDateTimes", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        ::QList<QDateTime> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::setExDateTimes(const QList<QDateTime>&)
            cppSelf->setExDateTimes(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_setExDates(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::setExDates(const QList<QDate>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_QDate_IDX], (pyArg)))) {
        overloadId = 0; // Recurrence::setExDates(const QList<QDate>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setExDates", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        ::QList<QDate> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::setExDates(const QList<QDate>&)
            cppSelf->setExDates(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_setFrequency(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::setFrequency(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // Recurrence::setFrequency(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFrequency", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::setFrequency(int)
            cppSelf->setFrequency(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_setHourly(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::setHourly(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // Recurrence::setHourly(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHourly", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::setHourly(int)
            cppSelf->setHourly(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_setMinutely(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::setMinutely(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // Recurrence::setMinutely(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMinutely", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::setMinutely(int)
            cppSelf->setMinutely(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_setMonthly(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::setMonthly(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // Recurrence::setMonthly(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMonthly", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::setMonthly(int)
            cppSelf->setMonthly(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_setMonthlyDate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::setMonthlyDate(const QList<int>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_int_IDX], (pyArg)))) {
        overloadId = 0; // Recurrence::setMonthlyDate(const QList<int>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMonthlyDate", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        ::QList<int> cppArg0_local;
        ::QList<int> *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::setMonthlyDate(const QList<int>&)
            cppSelf->setMonthlyDate(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_setNewRecurrenceType(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setNewRecurrenceType", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Recurrence::setNewRecurrenceType(KCalendarCore::RecurrenceRule::PeriodType,int)->KCalendarCore::RecurrenceRule*
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_PeriodType_IDX]))), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // Recurrence::setNewRecurrenceType(KCalendarCore::RecurrenceRule::PeriodType,int)->KCalendarCore::RecurrenceRule*
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setNewRecurrenceType", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        ::KCalendarCore::RecurrenceRule::PeriodType cppArg0{KCalendarCore::RecurrenceRule::rNone};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::setNewRecurrenceType(KCalendarCore::RecurrenceRule::PeriodType,int)->KCalendarCore::RecurrenceRule*
            KCalendarCore::RecurrenceRule * cppResult = cppSelf->setNewRecurrenceType(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_setRDateTimes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::setRDateTimes(const QList<QDateTime>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_QDateTime_IDX], (pyArg)))) {
        overloadId = 0; // Recurrence::setRDateTimes(const QList<QDateTime>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRDateTimes", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        ::QList<QDateTime> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::setRDateTimes(const QList<QDateTime>&)
            cppSelf->setRDateTimes(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_setRDates(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::setRDates(const QList<QDate>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_QDate_IDX], (pyArg)))) {
        overloadId = 0; // Recurrence::setRDates(const QList<QDate>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRDates", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        ::QList<QDate> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::setRDates(const QList<QDate>&)
            cppSelf->setRDates(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_setRecurReadOnly(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::setRecurReadOnly(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // Recurrence::setRecurReadOnly(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRecurReadOnly", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::setRecurReadOnly(bool)
            cppSelf->setRecurReadOnly(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_setStartDateTime(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setStartDateTime", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Recurrence::setStartDateTime(const QDateTime&,bool)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
        overloadId = 0; // Recurrence::setStartDateTime(const QDateTime&,bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setStartDateTime", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        bool cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::setStartDateTime(const QDateTime&,bool)
            cppSelf->setStartDateTime(*cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_setWeekly(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setWeekly", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:setWeekly", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Recurrence::setWeekly(int,const QBitArray&,int=)
    // 1: Recurrence::setWeekly(int,int=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // setWeekly(int,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 1; // Recurrence::setWeekly(int,int=)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBitArray_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // setWeekly(int,QBitArray,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                overloadId = 0; // Recurrence::setWeekly(int,const QBitArray&,int=)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setWeekly", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setWeekly(int freq, const QBitArray &days, int weekStart)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"weekStart", 2}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[2] != nullptr && !((pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))))) {
                    Py_XINCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setWeekly", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QBitArray cppArg1_local;
            ::QBitArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            int cppArg2 = 1;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Recurrence::setWeekly(int,const QBitArray&,int=)
                cppSelf->setWeekly(cppArg0, *cppArg1, cppArg2);
            }
            break;
        }
        case 1: // setWeekly(int freq, int weekStart)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"weekStart", 1}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))))) {
                    Py_XINCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setWeekly", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1 = 1;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Recurrence::setWeekly(int,int=)
                cppSelf->setWeekly(cppArg0, cppArg1);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_setYearly(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::setYearly(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // Recurrence::setYearly(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setYearly", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::setYearly(int)
            cppSelf->setYearly(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_setYearlyDate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::setYearlyDate(const QList<int>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_int_IDX], (pyArg)))) {
        overloadId = 0; // Recurrence::setYearlyDate(const QList<int>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setYearlyDate", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        ::QList<int> cppArg0_local;
        ::QList<int> *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::setYearlyDate(const QList<int>&)
            cppSelf->setYearlyDate(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_setYearlyDay(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::setYearlyDay(const QList<int>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_int_IDX], (pyArg)))) {
        overloadId = 0; // Recurrence::setYearlyDay(const QList<int>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setYearlyDay", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        ::QList<int> cppArg0_local;
        ::QList<int> *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::setYearlyDay(const QList<int>&)
            cppSelf->setYearlyDay(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_setYearlyMonth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Recurrence::setYearlyMonth(const QList<int>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_int_IDX], (pyArg)))) {
        overloadId = 0; // Recurrence::setYearlyMonth(const QList<int>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setYearlyMonth", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        ::QList<int> cppArg0_local;
        ::QList<int> *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::setYearlyMonth(const QList<int>&)
            cppSelf->setYearlyMonth(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_shiftTimes(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "shiftTimes", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Recurrence::shiftTimes(const QTimeZone&,const QTimeZone&)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[1])))) {
        overloadId = 0; // Recurrence::shiftTimes(const QTimeZone&,const QTimeZone&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "shiftTimes", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QTimeZone cppArg0_local;
        ::QTimeZone *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QTimeZone cppArg1_local;
        ::QTimeZone *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::shiftTimes(const QTimeZone&,const QTimeZone&)
            cppSelf->shiftTimes(*cppArg0, *cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_startDate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Recurrence::startDate()const->QDate
        QDate cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->startDate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_startDateTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Recurrence::startDateTime()const->QDateTime
        QDateTime cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->startDateTime();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_timesInInterval(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "timesInInterval", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Recurrence::timesInInterval(const QDateTime&,const QDateTime&)const->QList<QDateTime>
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[1])))) {
        overloadId = 0; // Recurrence::timesInInterval(const QDateTime&,const QDateTime&)const->QList<QDateTime>
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "timesInInterval", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QDateTime cppArg1_local;
        ::QDateTime *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Recurrence::timesInInterval(const QDateTime&,const QDateTime&)const->QList<QDateTime>
            QList<QDateTime> cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->timesInInterval(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_QDateTime_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_unsetRecurs(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Recurrence::unsetRecurs()
        cppSelf->unsetRecurs();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_updated(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Recurrence::updated()
        cppSelf->updated();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_weekStart(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Recurrence::weekStart()const->int
        int cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->weekStart();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_yearDates(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Recurrence::yearDates()const->QList<int>
        QList<int> cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->yearDates();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_int_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_yearDays(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Recurrence::yearDays()const->QList<int>
        QList<int> cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->yearDays();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_int_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc_yearMonths(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Recurrence::yearMonths()const->QList<int>
        QList<int> cppResult = const_cast<const ::KCalendarCore::Recurrence *>(cppSelf)->yearMonths();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_int_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyMethodDef Sbk_KCalendarCore_RecurrenceMethod_recurrenceType = {"recurrenceType", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_recurrenceType), METH_VARARGS|METH_STATIC, nullptr};


static const char *Sbk_KCalendarCore_Recurrence_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_KCalendarCore_Recurrence_methods[] = {
    {"addExDate", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_addExDate), METH_O, nullptr},
    {"addExDateTime", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_addExDateTime), METH_O, nullptr},
    {"addExRule", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_addExRule), METH_O, nullptr},
    {"addMonthlyDate", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_addMonthlyDate), METH_O, nullptr},
    {"addMonthlyPos", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_addMonthlyPos), METH_VARARGS, nullptr},
    {"addObserver", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_addObserver), METH_O, nullptr},
    {"addRDate", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_addRDate), METH_O, nullptr},
    {"addRDateTime", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_addRDateTime), METH_O, nullptr},
    {"addRDateTimePeriod", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_addRDateTimePeriod), METH_O, nullptr},
    {"addRRule", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_addRRule), METH_O, nullptr},
    {"addWeeklyDays", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_addWeeklyDays), METH_O, nullptr},
    {"addYearlyDate", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_addYearlyDate), METH_O, nullptr},
    {"addYearlyDay", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_addYearlyDay), METH_O, nullptr},
    {"addYearlyMonth", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_addYearlyMonth), METH_O, nullptr},
    {"addYearlyPos", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_addYearlyPos), METH_VARARGS, nullptr},
    {"allDay", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_allDay), METH_NOARGS, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_clear), METH_NOARGS, nullptr},
    {"days", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_days), METH_NOARGS, nullptr},
    {"defaultRRule", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_defaultRRule), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"defaultRRuleConst", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_defaultRRuleConst), METH_NOARGS, nullptr},
    {"deleteExRule", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_deleteExRule), METH_O, nullptr},
    {"deleteRRule", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_deleteRRule), METH_O, nullptr},
    {"dump", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_dump), METH_NOARGS, nullptr},
    {"duration", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_duration), METH_NOARGS, nullptr},
    {"durationTo", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_durationTo), METH_O, nullptr},
    {"endDate", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_endDate), METH_NOARGS, nullptr},
    {"endDateTime", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_endDateTime), METH_NOARGS, nullptr},
    {"exDateTimes", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_exDateTimes), METH_NOARGS, nullptr},
    {"exDates", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_exDates), METH_NOARGS, nullptr},
    {"exRules", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_exRules), METH_NOARGS, nullptr},
    {"frequency", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_frequency), METH_NOARGS, nullptr},
    {"getNextDateTime", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_getNextDateTime), METH_O, nullptr},
    {"getPreviousDateTime", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_getPreviousDateTime), METH_O, nullptr},
    {"monthDays", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_monthDays), METH_NOARGS, nullptr},
    {"rDateTimePeriod", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_rDateTimePeriod), METH_O, nullptr},
    {"rDateTimes", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_rDateTimes), METH_NOARGS, nullptr},
    {"rDates", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_rDates), METH_NOARGS, nullptr},
    {"rRules", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_rRules), METH_NOARGS, nullptr},
    {"recurReadOnly", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_recurReadOnly), METH_NOARGS, nullptr},
    {"recurTimesOn", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_recurTimesOn), METH_VARARGS, nullptr},
    {"recurrenceChanged", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_recurrenceChanged), METH_O, nullptr},
    {"recurrenceType", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_recurrenceType), METH_VARARGS|METH_STATIC, nullptr},
    {"recurs", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_recurs), METH_NOARGS, nullptr},
    {"recursAt", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_recursAt), METH_O, nullptr},
    {"recursOn", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_recursOn), METH_VARARGS, nullptr},
    {"removeExRule", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_removeExRule), METH_O, nullptr},
    {"removeObserver", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_removeObserver), METH_O, nullptr},
    {"removeRRule", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_removeRRule), METH_O, nullptr},
    {"setAllDay", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_setAllDay), METH_O, nullptr},
    {"setDaily", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_setDaily), METH_O, nullptr},
    {"setDuration", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_setDuration), METH_O, nullptr},
    {"setEndDate", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_setEndDate), METH_O, nullptr},
    {"setEndDateTime", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_setEndDateTime), METH_O, nullptr},
    {"setExDateTimes", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_setExDateTimes), METH_O, nullptr},
    {"setExDates", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_setExDates), METH_O, nullptr},
    {"setFrequency", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_setFrequency), METH_O, nullptr},
    {"setHourly", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_setHourly), METH_O, nullptr},
    {"setMinutely", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_setMinutely), METH_O, nullptr},
    {"setMonthly", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_setMonthly), METH_O, nullptr},
    {"setMonthlyDate", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_setMonthlyDate), METH_O, nullptr},
    {"setNewRecurrenceType", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_setNewRecurrenceType), METH_VARARGS, nullptr},
    {"setRDateTimes", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_setRDateTimes), METH_O, nullptr},
    {"setRDates", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_setRDates), METH_O, nullptr},
    {"setRecurReadOnly", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_setRecurReadOnly), METH_O, nullptr},
    {"setStartDateTime", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_setStartDateTime), METH_VARARGS, nullptr},
    {"setWeekly", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_setWeekly), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setYearly", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_setYearly), METH_O, nullptr},
    {"setYearlyDate", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_setYearlyDate), METH_O, nullptr},
    {"setYearlyDay", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_setYearlyDay), METH_O, nullptr},
    {"setYearlyMonth", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_setYearlyMonth), METH_O, nullptr},
    {"shiftTimes", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_shiftTimes), METH_VARARGS, nullptr},
    {"startDate", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_startDate), METH_NOARGS, nullptr},
    {"startDateTime", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_startDateTime), METH_NOARGS, nullptr},
    {"timesInInterval", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_timesInInterval), METH_VARARGS, nullptr},
    {"unsetRecurs", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_unsetRecurs), METH_NOARGS, nullptr},
    {"updated", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_updated), METH_NOARGS, nullptr},
    {"weekStart", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_weekStart), METH_NOARGS, nullptr},
    {"yearDates", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_yearDates), METH_NOARGS, nullptr},
    {"yearDays", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_yearDays), METH_NOARGS, nullptr},
    {"yearMonths", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceFunc_yearMonths), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_KCalendarCore_Recurrence_getattro(PyObject *self, PyObject *name)
{
    PySide::Feature::Select(self);
    // Search the method in the instance dict
    auto *ob_dict = SbkObject_GetDict_NoRef(self);
    if (auto *meth = PyDict_GetItem(ob_dict, name)) {
        Py_INCREF(meth);
        return meth;
    }
    // Search the method in the type dict
    if (Shiboken::Object::isUserType(self)) {
        Shiboken::AutoDecRef tmp(_Pep_PrivateMangle(self, name));
        Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
        if (auto *meth = PyDict_GetItem(tpDict.object(), tmp)) {
            if (std::strcmp(Py_TYPE(meth)->tp_name, "compiled_function") == 0) {
                auto descrGetFunc = reinterpret_cast<descrgetfunc>(PyType_GetSlot(Py_TYPE(meth), Py_tp_descr_get));
                ;
                return descrGetFunc(meth, self, nullptr);
            }
            return PyFunction_Check(meth) ? PyMethod_New(meth, self)
                                          : PyObject_GenericGetAttr(self, name);
        }
    }
    static PyMethodDef non_static_Sbk_KCalendarCore_RecurrenceMethod_recurrenceType = {
        Sbk_KCalendarCore_RecurrenceMethod_recurrenceType.ml_name,
        Sbk_KCalendarCore_RecurrenceMethod_recurrenceType.ml_meth,
        Sbk_KCalendarCore_RecurrenceMethod_recurrenceType.ml_flags & (~METH_STATIC),
        Sbk_KCalendarCore_RecurrenceMethod_recurrenceType.ml_doc,
    };
    if (PyUnicode_CompareWithASCIIString(name, "recurrenceType") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_KCalendarCore_RecurrenceMethod_recurrenceType, self, 0);
    return PyObject_GenericGetAttr(self, name);
}

static int Sbk_KCalendarCore_Recurrence_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<RecurrenceWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: Recurrence::operator<<(QDataStream&)->QDataStream& [free reverse operator]
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // Recurrence::operator<<(QDataStream&)->QDataStream& [free reverse operator]
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Recurrence::operator<<(QDataStream&)->QDataStream& [free reverse operator]
                QDataStream & cppResult = (*cppArg0) << (cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceFunc___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: Recurrence::operator>>(QDataStream&)->QDataStream& [free reverse operator]
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // Recurrence::operator>>(QDataStream&)->QDataStream& [free reverse operator]
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator>>", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Recurrence::operator>>(QDataStream&)->QDataStream& [free reverse operator]
                QDataStream & cppResult = (*cppArg0) >> (cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    return Sbk_ReturnFromPython_Result(pyResult);
}

// Rich comparison
static PyObject * Sbk_KCalendarCore_Recurrence_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto &cppSelf = *reinterpret_cast< ::KCalendarCore::Recurrence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), (pyArg)))) {
                // Recurrence::operator!=(const KCalendarCore::Recurrence&)const->bool
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::KCalendarCore::Recurrence *cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), (pyArg)))) {
                // Recurrence::operator==(const KCalendarCore::Recurrence&)const->bool
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::KCalendarCore::Recurrence *cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_KCalendarCore_Recurrence_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_KCalendarCore_Recurrence_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_KCalendarCore_Recurrence_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_getattro,    reinterpret_cast<void *>(Sbk_KCalendarCore_Recurrence_getattro)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_KCalendarCore_Recurrence_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_KCalendarCore_Recurrence_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_KCalendarCore_Recurrence_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_KCalendarCore_Recurrence_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_KCalendarCore_Recurrence_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_KCalendarCore_Recurrence_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_KCalendarCore_RecurrenceFunc___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_KCalendarCore_RecurrenceFunc___rshift__)},
    {0, nullptr}
};
static PyType_Spec Sbk_KCalendarCore_Recurrence_spec = {
    "1:KCalendarCore.KCalendarCore.Recurrence",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_KCalendarCore_Recurrence_slots
};

} //extern "C"

static void *Sbk_KCalendarCore_Recurrence_typeDiscovery([[maybe_unused]] void *cptr, [[maybe_unused]] PyTypeObject *instanceType)
{
    if (instanceType == Shiboken::SbkType< ::KCalendarCore::RecurrenceRule::RuleObserver >())
        return dynamic_cast< ::KCalendarCore::Recurrence *>(reinterpret_cast< ::KCalendarCore::RecurrenceRule::RuleObserver *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Recurrence_PythonToCpp_Recurrence_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_KCalendarCore_Recurrence_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Recurrence_PythonToCpp_Recurrence_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_KCalendarCore_Recurrence_TypeF()))
        return Recurrence_PythonToCpp_Recurrence_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Recurrence_PTR_CppToPython_Recurrence(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_KCalendarCore_Recurrence_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::KCalendarCore::Recurrence *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_KCalendarCore_Recurrence_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *KCalendarCore_Recurrence_SignatureStrings[] = {
    "1:KCalendarCore.KCalendarCore.Recurrence(self)",
    "0:KCalendarCore.KCalendarCore.Recurrence(self,r:KCalendarCore.KCalendarCore.Recurrence)",
    "KCalendarCore.KCalendarCore.Recurrence.addExDate(self,exdate:PySide6.QtCore.QDate)",
    "KCalendarCore.KCalendarCore.Recurrence.addExDateTime(self,exdate:PySide6.QtCore.QDateTime)",
    "KCalendarCore.KCalendarCore.Recurrence.addExRule(self,exrule:KCalendarCore.KCalendarCore.RecurrenceRule)",
    "KCalendarCore.KCalendarCore.Recurrence.addMonthlyDate(self,day:short)",
    "1:KCalendarCore.KCalendarCore.Recurrence.addMonthlyPos(self,pos:short,days:typing.Union[PySide6.QtCore.QBitArray, qsizetype])",
    "0:KCalendarCore.KCalendarCore.Recurrence.addMonthlyPos(self,pos:short,day:ushort)",
    "KCalendarCore.KCalendarCore.Recurrence.addObserver(self,observer:KCalendarCore.KCalendarCore.Recurrence.RecurrenceObserver)",
    "KCalendarCore.KCalendarCore.Recurrence.addRDate(self,rdate:PySide6.QtCore.QDate)",
    "KCalendarCore.KCalendarCore.Recurrence.addRDateTime(self,rdate:PySide6.QtCore.QDateTime)",
    "KCalendarCore.KCalendarCore.Recurrence.addRDateTimePeriod(self,period:KCalendarCore.KCalendarCore.Period)",
    "KCalendarCore.KCalendarCore.Recurrence.addRRule(self,rrule:KCalendarCore.KCalendarCore.RecurrenceRule)",
    "KCalendarCore.KCalendarCore.Recurrence.addWeeklyDays(self,days:typing.Union[PySide6.QtCore.QBitArray, qsizetype])",
    "KCalendarCore.KCalendarCore.Recurrence.addYearlyDate(self,date:int)",
    "KCalendarCore.KCalendarCore.Recurrence.addYearlyDay(self,day:int)",
    "KCalendarCore.KCalendarCore.Recurrence.addYearlyMonth(self,_rNum:short)",
    "KCalendarCore.KCalendarCore.Recurrence.addYearlyPos(self,pos:short,days:typing.Union[PySide6.QtCore.QBitArray, qsizetype])",
    "KCalendarCore.KCalendarCore.Recurrence.allDay(self)->bool",
    "KCalendarCore.KCalendarCore.Recurrence.clear(self)",
    "KCalendarCore.KCalendarCore.Recurrence.days(self)->PySide6.QtCore.QBitArray",
    "KCalendarCore.KCalendarCore.Recurrence.defaultRRule(self,create:bool=false)->KCalendarCore.KCalendarCore.RecurrenceRule",
    "KCalendarCore.KCalendarCore.Recurrence.defaultRRuleConst(self)->KCalendarCore.KCalendarCore.RecurrenceRule",
    "KCalendarCore.KCalendarCore.Recurrence.deleteExRule(self,exrule:KCalendarCore.KCalendarCore.RecurrenceRule)",
    "KCalendarCore.KCalendarCore.Recurrence.deleteRRule(self,rrule:KCalendarCore.KCalendarCore.RecurrenceRule)",
    "KCalendarCore.KCalendarCore.Recurrence.dump(self)",
    "KCalendarCore.KCalendarCore.Recurrence.duration(self)->int",
    "1:KCalendarCore.KCalendarCore.Recurrence.durationTo(self,date:PySide6.QtCore.QDate)->int",
    "0:KCalendarCore.KCalendarCore.Recurrence.durationTo(self,dt:PySide6.QtCore.QDateTime)->int",
    "KCalendarCore.KCalendarCore.Recurrence.endDate(self)->PySide6.QtCore.QDate",
    "KCalendarCore.KCalendarCore.Recurrence.endDateTime(self)->PySide6.QtCore.QDateTime",
    "KCalendarCore.KCalendarCore.Recurrence.exDateTimes(self)->QList[PySide6.QtCore.QDateTime]",
    "KCalendarCore.KCalendarCore.Recurrence.exDates(self)->QList[PySide6.QtCore.QDate]",
    "KCalendarCore.KCalendarCore.Recurrence.exRules(self)->QList[KCalendarCore.KCalendarCore.RecurrenceRule]",
    "KCalendarCore.KCalendarCore.Recurrence.frequency(self)->int",
    "KCalendarCore.KCalendarCore.Recurrence.getNextDateTime(self,preDateTime:PySide6.QtCore.QDateTime)->PySide6.QtCore.QDateTime",
    "KCalendarCore.KCalendarCore.Recurrence.getPreviousDateTime(self,afterDateTime:PySide6.QtCore.QDateTime)->PySide6.QtCore.QDateTime",
    "KCalendarCore.KCalendarCore.Recurrence.monthDays(self)->QList[int]",
    "KCalendarCore.KCalendarCore.Recurrence.rDateTimePeriod(self,rdate:PySide6.QtCore.QDateTime)->KCalendarCore.KCalendarCore.Period",
    "KCalendarCore.KCalendarCore.Recurrence.rDateTimes(self)->QList[PySide6.QtCore.QDateTime]",
    "KCalendarCore.KCalendarCore.Recurrence.rDates(self)->QList[PySide6.QtCore.QDate]",
    "KCalendarCore.KCalendarCore.Recurrence.rRules(self)->QList[KCalendarCore.KCalendarCore.RecurrenceRule]",
    "KCalendarCore.KCalendarCore.Recurrence.recurReadOnly(self)->bool",
    "KCalendarCore.KCalendarCore.Recurrence.recurTimesOn(self,date:PySide6.QtCore.QDate,timeZone:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])->QList[PySide6.QtCore.QTime]",
    "KCalendarCore.KCalendarCore.Recurrence.recurrenceChanged(self,arg__1:KCalendarCore.KCalendarCore.RecurrenceRule)",
    "1:KCalendarCore.KCalendarCore.Recurrence.recurrenceType(self)->ushort",
    "0:KCalendarCore.KCalendarCore.Recurrence.recurrenceType(rrule:KCalendarCore.KCalendarCore.RecurrenceRule)->ushort",
    "KCalendarCore.KCalendarCore.Recurrence.recurs(self)->bool",
    "KCalendarCore.KCalendarCore.Recurrence.recursAt(self,dt:PySide6.QtCore.QDateTime)->bool",
    "KCalendarCore.KCalendarCore.Recurrence.recursOn(self,date:PySide6.QtCore.QDate,timeZone:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])->bool",
    "KCalendarCore.KCalendarCore.Recurrence.removeExRule(self,exrule:KCalendarCore.KCalendarCore.RecurrenceRule)",
    "KCalendarCore.KCalendarCore.Recurrence.removeObserver(self,observer:KCalendarCore.KCalendarCore.Recurrence.RecurrenceObserver)",
    "KCalendarCore.KCalendarCore.Recurrence.removeRRule(self,rrule:KCalendarCore.KCalendarCore.RecurrenceRule)",
    "KCalendarCore.KCalendarCore.Recurrence.setAllDay(self,allDay:bool)",
    "KCalendarCore.KCalendarCore.Recurrence.setDaily(self,freq:int)",
    "KCalendarCore.KCalendarCore.Recurrence.setDuration(self,duration:int)",
    "KCalendarCore.KCalendarCore.Recurrence.setEndDate(self,endDate:PySide6.QtCore.QDate)",
    "KCalendarCore.KCalendarCore.Recurrence.setEndDateTime(self,endDateTime:PySide6.QtCore.QDateTime)",
    "KCalendarCore.KCalendarCore.Recurrence.setExDateTimes(self,exdates:QList[PySide6.QtCore.QDateTime])",
    "KCalendarCore.KCalendarCore.Recurrence.setExDates(self,exdates:QList[PySide6.QtCore.QDate])",
    "KCalendarCore.KCalendarCore.Recurrence.setFrequency(self,freq:int)",
    "KCalendarCore.KCalendarCore.Recurrence.setHourly(self,freq:int)",
    "KCalendarCore.KCalendarCore.Recurrence.setMinutely(self,freq:int)",
    "KCalendarCore.KCalendarCore.Recurrence.setMonthly(self,freq:int)",
    "KCalendarCore.KCalendarCore.Recurrence.setMonthlyDate(self,monthlyDays:QList[int])",
    "KCalendarCore.KCalendarCore.Recurrence.setNewRecurrenceType(self,type:KCalendarCore.KCalendarCore.RecurrenceRule.PeriodType,freq:int)->KCalendarCore.KCalendarCore.RecurrenceRule",
    "KCalendarCore.KCalendarCore.Recurrence.setRDateTimes(self,rdates:QList[PySide6.QtCore.QDateTime])",
    "KCalendarCore.KCalendarCore.Recurrence.setRDates(self,rdates:QList[PySide6.QtCore.QDate])",
    "KCalendarCore.KCalendarCore.Recurrence.setRecurReadOnly(self,readOnly:bool)",
    "KCalendarCore.KCalendarCore.Recurrence.setStartDateTime(self,start:PySide6.QtCore.QDateTime,isAllDay:bool)",
    "1:KCalendarCore.KCalendarCore.Recurrence.setWeekly(self,freq:int,days:typing.Union[PySide6.QtCore.QBitArray, qsizetype],weekStart:int=1)",
    "0:KCalendarCore.KCalendarCore.Recurrence.setWeekly(self,freq:int,weekStart:int=1)",
    "KCalendarCore.KCalendarCore.Recurrence.setYearly(self,freq:int)",
    "KCalendarCore.KCalendarCore.Recurrence.setYearlyDate(self,dates:QList[int])",
    "KCalendarCore.KCalendarCore.Recurrence.setYearlyDay(self,days:QList[int])",
    "KCalendarCore.KCalendarCore.Recurrence.setYearlyMonth(self,months:QList[int])",
    "KCalendarCore.KCalendarCore.Recurrence.shiftTimes(self,oldZone:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization],newZone:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])",
    "KCalendarCore.KCalendarCore.Recurrence.startDate(self)->PySide6.QtCore.QDate",
    "KCalendarCore.KCalendarCore.Recurrence.startDateTime(self)->PySide6.QtCore.QDateTime",
    "KCalendarCore.KCalendarCore.Recurrence.timesInInterval(self,start:PySide6.QtCore.QDateTime,end:PySide6.QtCore.QDateTime)->QList[PySide6.QtCore.QDateTime]",
    "KCalendarCore.KCalendarCore.Recurrence.unsetRecurs(self)",
    "KCalendarCore.KCalendarCore.Recurrence.updated(self)",
    "KCalendarCore.KCalendarCore.Recurrence.weekStart(self)->int",
    "KCalendarCore.KCalendarCore.Recurrence.yearDates(self)->QList[int]",
    "KCalendarCore.KCalendarCore.Recurrence.yearDays(self)->QList[int]",
    "KCalendarCore.KCalendarCore.Recurrence.yearMonths(self)->QList[int]",
    "KCalendarCore.KCalendarCore.Recurrence.__lshift__(self,out:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "KCalendarCore.KCalendarCore.Recurrence.__rshift__(self,in:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "KCalendarCore.KCalendarCore.Recurrence.__ne__(self,r:KCalendarCore.KCalendarCore.Recurrence)->bool",
    "KCalendarCore.KCalendarCore.Recurrence.__eq__(self,r:KCalendarCore.KCalendarCore.Recurrence)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t KCalendarCore_Recurrence_SignatureByteSize = 1019;
static constexpr uint8_t KCalendarCore_Recurrence_SignatureBytes[1019] = {
    0x78, 0xda, 0xc5, 0x59, 0x5b, 0x4f, 0xdb, 0x30, 0x14, 0x7e, 0xe7, 0x57, 0xf0, 0xb8, 0x4a, 0x59,
    0x45, 0x5f, 0xf6, 0x50, 0x89, 0x49, 0xac, 0x30, 0x0d, 0x6d, 0x40, 0x09, 0x4c, 0xd3, 0x86, 0x50,
    0x64, 0x9a, 0xd3, 0xd6, 0x5a, 0x6a, 0x97, 0x63, 0x07, 0xc8, 0x7e, 0xfd, 0xec, 0x38, 0xb7, 0xde,
    0xed, 0x24, 0x2d, 0x6f, 0x6e, 0x62, 0x7f, 0x9f, 0x7d, 0xf2, 0x9d, 0x8b, 0x4f, 0x7b, 0xfd, 0xef,
    0x03, 0x12, 0x01, 0x0b, 0x09, 0x0e, 0x38, 0x42, 0x77, 0xf1, 0x97, 0x0f, 0xa3, 0x18, 0x11, 0xd8,
    0x08, 0x3e, 0x08, 0x88, 0xc6, 0x9d, 0xa3, 0x13, 0x97, 0xe9, 0x1e, 0x5a, 0xce, 0xee, 0x1c, 0xd9,
    0xcd, 0xeb, 0x92, 0x30, 0xbc, 0x78, 0x3b, 0x27, 0x32, 0xc3, 0x87, 0xb7, 0x50, 0x8d, 0xfb, 0xc3,
    0xe4, 0x8e, 0x86, 0xf0, 0xa9, 0x7b, 0x2b, 0xd3, 0xf9, 0xb7, 0x7a, 0x82, 0x3b, 0xe4, 0x3d, 0x9d,
    0xed, 0x86, 0xd5, 0x93, 0xdc, 0xa0, 0xfd, 0x38, 0x2a, 0x60, 0x51, 0x8d, 0x2d, 0x4d, 0xa2, 0x97,
    0xb9, 0x10, 0x5d, 0x71, 0x26, 0xa7, 0x51, 0x52, 0xda, 0x26, 0x24, 0x49, 0x5f, 0x4c, 0x39, 0xca,
    0xce, 0x51, 0xaf, 0xef, 0x8c, 0x33, 0xe4, 0xc2, 0xc0, 0xcc, 0xb9, 0x30, 0x30, 0x1a, 0x50, 0xf4,
    0x65, 0x32, 0xa7, 0x6c, 0xd2, 0xfd, 0xc9, 0x28, 0x67, 0x0f, 0xcb, 0x06, 0xfa, 0x42, 0xe5, 0x19,
    0x22, 0x49, 0xbc, 0xe3, 0x67, 0x41, 0xff, 0x81, 0x9a, 0x0b, 0x8f, 0xf6, 0x92, 0xd9, 0xc9, 0xde,
    0x8f, 0xb3, 0xf3, 0xd8, 0xe3, 0xdd, 0x3c, 0x09, 0xc0, 0x17, 0x40, 0x83, 0xc6, 0xb3, 0x5f, 0xb6,
    0x1b, 0x2a, 0x87, 0x39, 0x8e, 0x0b, 0xb7, 0x5f, 0x7e, 0x0b, 0x6c, 0x45, 0xa6, 0xfe, 0xa2, 0x4a,
    0xb1, 0x35, 0x91, 0x16, 0xc0, 0x43, 0x40, 0xca, 0xc3, 0xcc, 0xf4, 0xe9, 0x78, 0xab, 0xa9, 0xcc,
    0x74, 0x27, 0xa6, 0xd2, 0x1b, 0x70, 0x8f, 0xce, 0xf0, 0x0b, 0xe0, 0xaf, 0xf6, 0x85, 0x44, 0x14,
    0xbe, 0x50, 0x4b, 0xba, 0xf6, 0x8c, 0xbf, 0x81, 0xe0, 0xa2, 0xf7, 0xa9, 0x6f, 0x43, 0x99, 0xac,
    0x83, 0x91, 0x94, 0x0e, 0x5c, 0x0b, 0x21, 0x75, 0x22, 0x83, 0x11, 0xe0, 0x75, 0x3c, 0xeb, 0x3b,
    0xbb, 0x8d, 0xc1, 0x69, 0x31, 0x06, 0xd8, 0x52, 0x47, 0x51, 0x7e, 0xfc, 0xce, 0xc7, 0xcf, 0x4f,
    0x9c, 0x47, 0xb6, 0x2b, 0x47, 0x91, 0xda, 0x72, 0x96, 0xa3, 0x2c, 0x97, 0x84, 0xb9, 0x3c, 0x14,
    0xd5, 0xa6, 0x53, 0x58, 0x63, 0xc1, 0x98, 0xc4, 0x91, 0xac, 0xc8, 0x7b, 0x84, 0xa0, 0x25, 0xa0,
    0xcf, 0x70, 0x3a, 0x26, 0x91, 0x00, 0xc5, 0x62, 0x2f, 0xf6, 0x3a, 0xbc, 0x03, 0xce, 0x84, 0xcc,
    0x0f, 0xb4, 0x0f, 0xaa, 0x08, 0x24, 0x1c, 0x26, 0x9f, 0x19, 0xae, 0x43, 0x04, 0x8b, 0x30, 0x9e,
    0xcd, 0x1d, 0x65, 0x13, 0x23, 0x91, 0x4a, 0xf9, 0xb9, 0xa5, 0x95, 0x8b, 0xda, 0x27, 0xd8, 0x7c,
    0xf1, 0x3d, 0xaf, 0x84, 0x89, 0xb5, 0x79, 0xc1, 0x00, 0x9f, 0xd4, 0x06, 0x96, 0x9b, 0x33, 0x83,
    0x81, 0xb6, 0x04, 0x56, 0x0f, 0x8b, 0xa8, 0xb6, 0xc6, 0x51, 0xf4, 0x3b, 0x47, 0xa8, 0x22, 0x83,
    0x6d, 0x80, 0xd3, 0xef, 0xad, 0x21, 0x8b, 0xca, 0xad, 0x70, 0xe5, 0xdb, 0x1f, 0x54, 0xc8, 0x87,
    0x4d, 0xc0, 0x8f, 0x6e, 0xc8, 0x16, 0xa8, 0x0e, 0x88, 0x5a, 0x99, 0x4b, 0x88, 0xf6, 0x92, 0xb6,
    0xe6, 0x19, 0x23, 0x3c, 0xc7, 0x6a, 0x94, 0x54, 0x15, 0x6a, 0xb9, 0x76, 0x02, 0xf2, 0x1a, 0xde,
    0xe4, 0x62, 0xa1, 0x31, 0x47, 0xc8, 0x1f, 0x6c, 0x13, 0x55, 0xd3, 0x6f, 0xa9, 0xb8, 0x87, 0x08,
    0x2f, 0x94, 0xc7, 0x62, 0x91, 0x9f, 0x8c, 0x25, 0xe0, 0x21, 0x76, 0x30, 0xd3, 0x89, 0xf3, 0xbc,
    0x92, 0x16, 0xcc, 0x37, 0x52, 0xf6, 0xb3, 0x36, 0x3e, 0xae, 0x2b, 0xa5, 0x76, 0x54, 0x6a, 0xdb,
    0xa3, 0xb5, 0x01, 0x72, 0xe6, 0x6f, 0xdb, 0x1f, 0xb0, 0x6d, 0x77, 0xc0, 0xc3, 0x78, 0x03, 0xea,
    0xa1, 0x0f, 0x24, 0xbc, 0x61, 0x51, 0xad, 0xca, 0x22, 0x05, 0x48, 0x2d, 0x7a, 0xc3, 0x76, 0x04,
    0x6d, 0x4f, 0xaa, 0x69, 0x7f, 0x38, 0x83, 0xed, 0x25, 0xd2, 0x7d, 0x36, 0xcb, 0x3b, 0xde, 0xf4,
    0xa6, 0x7b, 0xc9, 0xa8, 0xa4, 0x24, 0xa2, 0xff, 0xd2, 0xa0, 0xfe, 0xb8, 0xd1, 0xe2, 0x6e, 0x9f,
    0xb0, 0x18, 0x0e, 0xa6, 0x84, 0x4d, 0x20, 0x53, 0x27, 0xc1, 0x49, 0x10, 0xf4, 0x9c, 0x92, 0xab,
    0x75, 0xbe, 0x2b, 0x29, 0xef, 0x55, 0x21, 0x98, 0x9b, 0xdf, 0xdc, 0xe3, 0xec, 0x93, 0xdb, 0x12,
    0x8a, 0x73, 0x31, 0x50, 0x30, 0xba, 0xf0, 0x89, 0xda, 0x62, 0x11, 0x67, 0xd2, 0x26, 0x09, 0xbb,
    0xe3, 0xbe, 0xab, 0x00, 0xdd, 0xb6, 0x3b, 0xe3, 0x2f, 0x07, 0xaa, 0x15, 0x0d, 0xd7, 0xbb, 0x5d,
    0xf4, 0x0d, 0xfd, 0x21, 0x4a, 0x55, 0x01, 0xf2, 0xac, 0xbc, 0x1f, 0x79, 0xe6, 0xae, 0x94, 0x5e,
    0x30, 0x5c, 0x20, 0xce, 0x09, 0xcd, 0xe2, 0xa0, 0xa7, 0x0b, 0x05, 0xa7, 0x1b, 0xa6, 0x5e, 0x5e,
    0xad, 0x7e, 0xbd, 0xbc, 0xea, 0x74, 0x45, 0xb9, 0xa8, 0x14, 0x95, 0x5e, 0x56, 0x16, 0x36, 0x6b,
    0x8f, 0x94, 0xa0, 0x95, 0x36, 0x5e, 0xf9, 0xa0, 0x79, 0x9b, 0x44, 0x13, 0x2c, 0x15, 0x9b, 0x59,
    0x9f, 0x50, 0xf4, 0x77, 0xa4, 0x58, 0x77, 0x0e, 0x6b, 0x7c, 0x27, 0xec, 0xaf, 0x0b, 0x85, 0x61,
    0xad, 0xcf, 0xff, 0x8d, 0xc7, 0xd8, 0x44, 0x3e, 0x57, 0x94, 0xc5, 0x12, 0x1a, 0x21, 0x98, 0x0e,
    0x61, 0x63, 0x80, 0x52, 0x7f, 0xb3, 0xfc, 0x41, 0x92, 0x5b, 0x5a, 0x17, 0x7c, 0x2e, 0x90, 0xd7,
    0xf0, 0xea, 0xaf, 0x26, 0x3a, 0x4f, 0xf7, 0x3e, 0x1c, 0x02, 0x41, 0x56, 0xe9, 0xe9, 0xf5, 0xe5,
    0xc1, 0xf6, 0x71, 0x93, 0x57, 0x3b, 0xf6, 0x97, 0x94, 0x8c, 0xad, 0x0b, 0xd9, 0xaf, 0xe8, 0x18,
    0x5b, 0x95, 0xb1, 0xbf, 0x52, 0xd1, 0x79, 0x98, 0xfd, 0x72, 0x8e, 0x86, 0x77, 0x92, 0xe0, 0xd2,
    0x6d, 0x47, 0xe8, 0x47, 0x1b, 0xe3, 0x85, 0x47, 0xc5, 0x59, 0x35, 0xf0, 0x5a, 0x57, 0x42, 0x8a,
    0xcc, 0x74, 0x25, 0x17, 0x95, 0x5b, 0xb3, 0xa3, 0xe6, 0xbd, 0x2a, 0xac, 0x74, 0xf3, 0x1a, 0xe4,
    0xb4, 0xe7, 0xd0, 0x65, 0xdf, 0xb4, 0x91, 0x15, 0x44, 0x7b, 0x3c, 0xd3, 0x2e, 0xac, 0xef, 0x92,
    0xeb, 0x9a, 0xa7, 0x75, 0x7d, 0x71, 0xb5, 0x89, 0xda, 0x0c, 0xa9, 0xd2, 0x4c, 0x4d, 0x03, 0x45,
    0x3d, 0xb4, 0x29, 0x1d, 0xcb, 0x8a, 0xbb, 0xf1, 0x28, 0xdc, 0x47, 0x95, 0xe6, 0x31, 0x78, 0xdd,
    0x4b, 0xf5, 0x67, 0x7d, 0xce, 0xdc, 0x9d, 0xda, 0x68, 0x17, 0x89, 0x15, 0xdf, 0x6c, 0xe1, 0x8a,
    0xaf, 0x0b, 0x64, 0x71, 0xc9, 0x2e, 0x99, 0x54, 0x65, 0x1e, 0x89, 0xac, 0x5c, 0x5e, 0x01, 0x6d,
    0xab, 0xe3, 0x5b, 0xba, 0x60, 0xc7, 0x2c, 0x8f, 0x6d, 0xc2, 0xad, 0x21, 0x19, 0xcf, 0xb5, 0xbf,
    0x84, 0x6e, 0x8b, 0x0a, 0x6f, 0xaf, 0xd1, 0x24, 0x4a, 0x94, 0x63, 0xac, 0xe9, 0x06, 0xb8, 0xb4,
    0x49, 0x0c, 0x44, 0xd2, 0x10, 0x21, 0xf5, 0xcd, 0x06, 0x18, 0x41, 0x10, 0xa5, 0x9e, 0x19, 0x04,
    0x99, 0x5b, 0xc6, 0x6b, 0x55, 0x40, 0xee, 0xa4, 0x4a, 0x30, 0xb3, 0xf5, 0xea, 0xcb, 0x5e, 0xda,
    0x53, 0xe2, 0x02, 0x25, 0x65, 0xfb, 0x67, 0x64, 0x90, 0xb3, 0x59, 0xff, 0x1f, 0xef, 0x76, 0xdd,
    0x0b, 0x02, 0x78, 0xae, 0x4b, 0xf1, 0x1f, 0x4c, 0x52, 0xe3, 0x47
};
#endif

PyTypeObject *init_KCalendarCore_Recurrence(PyObject *enclosingClass)
{
    auto &typeStruct = SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_RuleObserver_IDX]));
    Shiboken::AutoDecRef Sbk_KCalendarCore_Recurrence_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "Recurrence",
        "KCalendarCore::Recurrence*",
        &Sbk_KCalendarCore_Recurrence_spec,
        &Shiboken::callCppDestructor< KCalendarCore::Recurrence >,
        Sbk_KCalendarCore_Recurrence_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, KCalendarCore_Recurrence_SignatureStrings);
#else
    InitSignatureBytes(pyType, KCalendarCore_Recurrence_SignatureBytes, KCalendarCore_Recurrence_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_KCalendarCore_Recurrence_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Recurrence_PythonToCpp_Recurrence_PTR,
        is_Recurrence_PythonToCpp_Recurrence_PTR_Convertible,
        Recurrence_PTR_CppToPython_Recurrence);

    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Recurrence");
    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Recurrence*");
    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Recurrence&");
    Shiboken::Conversions::registerConverterAlias(converter, "Recurrence");
    Shiboken::Conversions::registerConverterAlias(converter, "Recurrence*");
    Shiboken::Conversions::registerConverterAlias(converter, "Recurrence&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::KCalendarCore::Recurrence).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(RecurrenceWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(pyType, &Sbk_KCalendarCore_Recurrence_typeDiscovery);

    qRegisterMetaType< ::KCalendarCore::Recurrence *>();

    return pyType;
}
